==> hamjest-3.0.0-3.tgz: package/test/node/matchers/IsDefinedSpec.js <==
'use strict';

var __ = require('../../..');

describe('IsDefined', function () {

	describe('defined', function () {
		var sut;
		beforeEach(function () {
			sut = __.defined();
		});

		it('should match any value', function () {
			__.assertThat(sut.matches(0), __.is(true));
			__.assertThat(sut.matches(''), __.is(true));
			__.assertThat(sut.matches([]), __.is(true));
			__.assertThat(sut.matches({}), __.is(true));

			__.assertThat(sut.matches(), __.is(false));
			__.assertThat(sut.matches(undefined), __.is(false));
		});

		describe('description', function () {
			var description;

			beforeEach(function () {
				description = new __.Description();
			});

			it('should be concise', function () {

				sut.describeTo(description);

				__.assertThat(description.get(), __.equalTo('defined'));
			});

			it('should contain mismatched values', function () {
				var description = new __.Description();

				sut.describeMismatch({an: 'object'}, description);

				__.assertThat(description.get(), __.equalTo('was {"an":"object"}'));
			});
		});
	});

	describe('undefined', function () {
		var sut;
		beforeEach(function () {
			sut = __.undefined();
		});

		it('should not match any value', function () {
			__.assertThat(sut.matches(0), __.is(false));
			__.assertThat(sut.matches(''), __.is(false));
			__.assertThat(sut.matches([]), __.is(false));
			__.assertThat(sut.matches({}), __.is(false));

			__.assertThat(sut.matches(), __.is(true));
			__.assertThat(sut.matches(undefined), __.is(true));
		});

		describe('description', function () {
			var description;
			beforeEach(function () {
				description = new __.Description();
			});

			it('should be concise', function () {

				sut.describeTo(description);

				__.assertThat(description.get(), __.equalTo('not defined'));
			});

			it('should contain mismatched values', function () {
				var description = new __.Description();

				sut.describeMismatch({an: 'object'}, description);

				__.assertThat(description.get(), __.equalTo('was {"an":"object"}'));
			});
		});
	});

	it('should be available as "undef"', function () {
		__.assertThat(__.undef, __.equalTo(__.undefined));
	});

});

==> hamjest-3.0.0-4.tgz: package/test/node/matchers/IsDefinedSpec.js <==
'use strict';

const __ = require('../../..');

describe('IsDefined', () => {

	describe('defined', () => {
		let sut;
		beforeEach(() => {
			sut = __.defined();
		});

		it('should match any value', () => {
			__.assertThat(sut.matches(0), __.is(true));
			__.assertThat(sut.matches(''), __.is(true));
			__.assertThat(sut.matches([]), __.is(true));
			__.assertThat(sut.matches({}), __.is(true));

			__.assertThat(sut.matches(), __.is(false));
			__.assertThat(sut.matches(undefined), __.is(false));
		});

		describe('description', () => {
			let description;

			beforeEach(() => {
				description = new __.Description();
			});

			it('should be concise', () => {

				sut.describeTo(description);

				__.assertThat(description.get(), __.equalTo('defined'));
			});

			it('should contain mismatched values', () => {
				const description = new __.Description();

				sut.describeMismatch({an: 'object'}, description);

				__.assertThat(description.get(), __.equalTo('was {"an":"object"}'));
			});
		});
	});

	describe('undefined', () => {
		let sut;
		beforeEach(() => {
			sut = __.undefined();
		});

		it('should not match any value', () => {
			__.assertThat(sut.matches(0), __.is(false));
			__.assertThat(sut.matches(''), __.is(false));
			__.assertThat(sut.matches([]), __.is(false));
			__.assertThat(sut.matches({}), __.is(false));

			__.assertThat(sut.matches(), __.is(true));
			__.assertThat(sut.matches(undefined), __.is(true));
		});

		describe('description', () => {
			let description;
			beforeEach(() => {
				description = new __.Description();
			});

			it('should be concise', () => {

				sut.describeTo(description);

				__.assertThat(description.get(), __.equalTo('not defined'));
			});

			it('should contain mismatched values', () => {
				const description = new __.Description();

				sut.describeMismatch({an: 'object'}, description);

				__.assertThat(description.get(), __.equalTo('was {"an":"object"}'));
			});
		});
	});

	it('should be available as "undef"', () => {
		__.assertThat(__.undef, __.equalTo(__.undefined));
	});

});
